@@ -12,13 +12,14 @@
 #' @importFrom rlang .data
 RunPoissonRegression_Omnibus <- function(df, pyr0 = "pyr", event0 = "event", names = c("CONST"), term_n = c(0), tform = "loglin", keep_constant = c(0), a_n = c(0), modelform = "M", control = list(), strat_col = "null", model_control = list(), cons_mat = as.matrix(c(0)), cons_vec = c(0)) {
   func_t_start <- Sys.time()
+  initial_size <- nrow(df)
   if (class(df)[[1]] != "data.table") {
     tryCatch(
       {
-        setDT(df) # nocov
+        setDT(df)
       },
-      error = function(e) { # nocov
-        df <- data.table(df) # nocov
+      error = function(e) {
+        df <- data.table(df)
       }
     )
   }
@@ -28,8 +29,11 @@ RunPoissonRegression_Omnibus <- function(df, pyr0 = "pyr", event0 = "event", nam
     a_n <- list(a_n)
   }
   df <- df[get(pyr0) > 0, ]
-  if (min(keep_constant) > 0) {
-    stop("Error: Atleast one parameter must be free")
+  if (model_control$null == FALSE) {
+    if (min(keep_constant) > 0) {
+      stop("Error: Atleast one parameter must be free")
+    }
+    # A null model can have no free parameters
   }
   if (sum(df[, event0, with = FALSE]) == 0) {
     stop("Error: no events")
@@ -42,32 +46,23 @@ RunPoissonRegression_Omnibus <- function(df, pyr0 = "pyr", event0 = "event", nam
     }
   }
   if (model_control$strata == TRUE) {
-    val <- factorize(df, strat_col)
-    df0 <- val$df
-    df <- val$df
-    val_cols <- c()
-    for (col in val$cols) {
-      dftemp <- df[get(col) == 1, ]
-      temp <- sum(dftemp[, get(event0)])
-      if (temp == 0) {
-        if (control$verbose >= 2) {
-          warning(paste("Warning: no events for strata group:", col,
-            sep = " "
-          ))
-        }
-        df <- df[get(col) != 1, ]
-        df0 <- df0[get(col) != 1, ]
-      } else {
-        val_cols <- c(val_cols, col)
-      }
-      data.table::setkeyv(df0, c(pyr0, event0))
+    ## ------------------------------------------------------------------------------- ##
+    val <- Make_Interaction_Strata(df, event0, strat_col, control, TRUE)
+    df <- val$data
+    val_cols <- val$combs
+    strata_vals <- val$levels
+    ## ------------------------------------------------------------------------------- ##
+    if (control$verbose >= 3) {
+      message(paste("Note: ", length(strat_col), " strata used",
+        sep = ""
+      ))
     }
   } else {
-    df0 <- data.table::data.table("a" = c(0, 0))
     val <- list(cols = c("a"))
-    val_cols <- c("a")
+    val_cols <- c(event0)
+    strata_vals <- c(1)
   }
-  data.table::setkeyv(df, c(pyr0, event0))
+  data.table::setkeyv(df, val_cols)
   all_names <- unique(names)
   df <- Replace_Missing(df, all_names, 0.0, control$verbose)
   dfc <- match(names, all_names)
@@ -78,6 +73,7 @@ RunPoissonRegression_Omnibus <- function(df, pyr0 = "pyr", event0 = "event", nam
   for (i in a_n) {
     a_ns <- c(a_ns, i)
   }
+  run_size <- nrow(df)
   if (model_control$log_bound) {
     if ("maxiters" %in% names(control)) {
       # good
@@ -92,7 +88,7 @@ RunPoissonRegression_Omnibus <- function(df, pyr0 = "pyr", event0 = "event", nam
     e <- pois_Omnibus_Bounds_transition(
       as.matrix(df[, ce, with = FALSE]),
       term_n, tform, a_ns, dfc, x_all, 0, modelform, control,
-      keep_constant, term_tot, as.matrix(df0[, val_cols, with = FALSE]),
+      keep_constant, term_tot, strata_vals, as.matrix(df[, val_cols, with = FALSE]),
       model_control, cons_mat, cons_vec
     )
     if ("Status" %in% names(e)) {
@@ -112,7 +108,7 @@ RunPoissonRegression_Omnibus <- function(df, pyr0 = "pyr", event0 = "event", nam
         byrow = TRUE
       ), dfc, x_all, 0,
       modelform, control, keep_constant,
-      term_tot, as.matrix(df0[, val_cols,
+      term_tot, strata_vals, as.matrix(df[, val_cols,
         with = FALSE
       ]),
       model_control, cons_mat, cons_vec
@@ -125,9 +121,14 @@ RunPoissonRegression_Omnibus <- function(df, pyr0 = "pyr", event0 = "event", nam
   e$Parameter_Lists$keep_constant <- keep_constant
   e$Parameter_Lists$modelformula <- modelform
   e$Survival_Type <- "Poisson"
+  if (model_control$strata == TRUE) {
+    e$strata_levels <- length(strata_vals)
+  }
   e$modelcontrol <- model_control
   func_t_end <- Sys.time()
   e$RunTime <- func_t_end - func_t_start
+  e$UsedRecords <- run_size
+  e$RejectedRecords <- initial_size - run_size
   return(e)
 }
 
@@ -144,10 +145,10 @@ RunPoissonEventAssignment <- function(df, pyr0 = "pyr", event0 = "event", names
   if (class(df)[[1]] != "data.table") {
     tryCatch(
       {
-        setDT(df) # nocov
+        setDT(df)
       },
-      error = function(e) { # nocov
-        df <- data.table(df) # nocov
+      error = function(e) {
+        df <- data.table(df)
       }
     )
   }
@@ -171,27 +172,21 @@ RunPoissonEventAssignment <- function(df, pyr0 = "pyr", event0 = "event", names
     }
   }
   if (model_control$strata == TRUE) {
-    val <- factorize(df, strat_col)
-    df0 <- val$df
-    df <- val$df
-    val_cols <- c()
-    for (col in val$cols) {
-      dftemp <- df[get(col) == 1, ]
-      temp <- sum(dftemp[, get(event0)])
-      if (temp == 0) {
-        if (control$verbose >= 2) {
-          warning(paste("Warning: no events for strata group:", col,
-            sep = " "
-          ))
-        }
-      } else {
-        val_cols <- c(val_cols, col)
-      }
+    ## ------------------------------------------------------------------------------- ##
+    val <- Make_Interaction_Strata(df, event0, strat_col, control, TRUE, FALSE)
+    df <- val$data
+    val_cols <- val$combs
+    strata_vals <- val$levels
+    ## ------------------------------------------------------------------------------- ##
+    if (control$verbose >= 3) {
+      message(paste("Note: ", length(strat_col), " strata used",
+        sep = ""
+      ))
     }
   } else {
-    df0 <- data.table::data.table("a" = c(0, 0))
     val <- list(cols = c("a"))
-    val_cols <- c("a")
+    val_cols <- c(event0)
+    strata_vals <- c(1)
   }
   all_names <- unique(names)
   df <- Replace_Missing(df, all_names, 0.0, control$verbose)
@@ -204,8 +199,8 @@ RunPoissonEventAssignment <- function(df, pyr0 = "pyr", event0 = "event", names
     a_ns <- c(a_ns, i)
   }
   e <- Assigned_Event_Poisson_transition(
-    as.matrix(df[, ce, with = FALSE]),
-    as.matrix(df0[, val_cols,
+    as.matrix(df[, ce, with = FALSE]), strata_vals,
+    as.matrix(df[, val_cols,
       with = FALSE
     ]), term_n, tform,
     a_n, dfc, x_all, 0,
@@ -230,10 +225,10 @@ RunPoissonRegression_Residual <- function(df, pyr0 = "pyr", event0 = "event", na
   if (class(df)[[1]] != "data.table") {
     tryCatch(
       {
-        setDT(df) # nocov
+        setDT(df)
       },
-      error = function(e) { # nocov
-        df <- data.table(df) # nocov
+      error = function(e) {
+        df <- data.table(df)
       }
     )
   }
@@ -259,28 +254,21 @@ RunPoissonRegression_Residual <- function(df, pyr0 = "pyr", event0 = "event", na
     }
   }
   if (model_control$strata == TRUE) {
-    val <- factorize(df, strat_col)
-    df0 <- val$df
-    df <- val$df
-    val_cols <- c()
-    for (col in val$cols) {
-      dftemp <- df[get(col) == 1, ]
-      temp <- sum(dftemp[, get(event0)])
-      if (temp == 0) {
-        if (control$verbose >= 2) {
-          warning(paste("Warning: no events for strata group:",
-            col,
-            sep = " "
-          ))
-        }
-      } else {
-        val_cols <- c(val_cols, col)
-      }
+    ## ------------------------------------------------------------------------------- ##
+    val <- Make_Interaction_Strata(df, event0, strat_col, control, TRUE, FALSE)
+    df <- val$data
+    val_cols <- val$combs
+    strata_vals <- val$levels
+    ## ------------------------------------------------------------------------------- ##
+    if (control$verbose >= 3) {
+      message(paste("Note: ", length(strat_col), " strata used",
+        sep = ""
+      ))
     }
   } else {
-    df0 <- data.table::data.table("a" = c(0, 0))
     val <- list(cols = c("a"))
-    val_cols <- c("a")
+    val_cols <- c(event0)
+    strata_vals <- c(1)
   }
   all_names <- unique(names)
   df <- Replace_Missing(df, all_names, 0.0, control$verbose)
@@ -293,7 +281,7 @@ RunPoissonRegression_Residual <- function(df, pyr0 = "pyr", event0 = "event", na
     term_n, tform, a_n[[1]],
     dfc, x_all, 0, modelform,
     control, keep_constant,
-    term_tot, as.matrix(df0[, val_cols,
+    term_tot, strata_vals, as.matrix(df[, val_cols,
       with = FALSE
     ]),
     model_control
@@ -317,10 +305,10 @@ PoissonCurveSolver <- function(df, pyr0 = "pyr", event0 = "event", names = c("CO
   if (class(df)[[1]] != "data.table") {
     tryCatch(
       {
-        setDT(df) # nocov
+        setDT(df)
       },
-      error = function(e) { # nocov
-        df <- data.table(df) # nocov
+      error = function(e) {
+        df <- data.table(df)
       }
     )
   }
@@ -344,32 +332,23 @@ PoissonCurveSolver <- function(df, pyr0 = "pyr", event0 = "event", names = c("CO
     }
   }
   if (model_control$strata == TRUE) {
-    val <- factorize(df, strat_col)
-    df0 <- val$df
-    df <- val$df
-    val_cols <- c()
-    for (col in val$cols) {
-      dftemp <- df[get(col) == 1, ]
-      temp <- sum(dftemp[, get(event0)])
-      if (temp == 0) {
-        if (control$verbose >= 2) {
-          warning(paste("Warning: no events for strata group:", col,
-            sep = " "
-          ))
-        }
-        df <- df[get(col) != 1, ]
-        df0 <- df0[get(col) != 1, ]
-      } else {
-        val_cols <- c(val_cols, col)
-      }
-      data.table::setkeyv(df0, c(pyr0, event0))
+    ## ------------------------------------------------------------------------------- ##
+    val <- Make_Interaction_Strata(df, event0, strat_col, control, TRUE, TRUE)
+    df <- val$data
+    val_cols <- val$combs
+    strata_vals <- val$levels
+    ## ------------------------------------------------------------------------------- ##
+    if (control$verbose >= 3) {
+      message(paste("Note: ", length(strat_col), " strata used",
+        sep = ""
+      ))
     }
   } else {
-    df0 <- data.table::data.table("a" = c(0, 0))
     val <- list(cols = c("a"))
-    val_cols <- c("a")
+    val_cols <- c(event0)
+    strata_vals <- c(1)
   }
-  data.table::setkeyv(df, c(pyr0, event0))
+  data.table::setkeyv(df, val_cols)
   all_names <- unique(names)
   df <- Replace_Missing(df, all_names, 0.0, control$verbose)
   dfc <- match(names, all_names)
@@ -397,7 +376,7 @@ PoissonCurveSolver <- function(df, pyr0 = "pyr", event0 = "event", names = c("CO
   e <- pois_Omnibus_CurveSearch_transition(
     as.matrix(df[, ce, with = FALSE]),
     term_n, tform, a_ns, dfc, x_all, 0, modelform, control,
-    keep_constant, term_tot, as.matrix(df0[, val_cols, with = FALSE]),
+    keep_constant, term_tot, strata_vals, as.matrix(df[, val_cols, with = FALSE]),
     model_control, cons_mat, cons_vec
   )
   e$Parameter_Lists$names <- names
@@ -405,6 +384,9 @@ PoissonCurveSolver <- function(df, pyr0 = "pyr", event0 = "event", names = c("CO
   e$Parameter_Lists$modelformula <- modelform
   e$Survival_Type <- "Poisson"
   e$modelcontrol <- model_control
+  if (model_control$strata == TRUE) {
+    e$strata_levels <- length(strata_vals)
+  }
   func_t_end <- Sys.time()
   e$RunTime <- func_t_end - func_t_start
   return(e)
@@ -426,13 +408,14 @@ PoissonCurveSolver <- function(df, pyr0 = "pyr", event0 = "event", names = c("CO
 #' @importFrom rlang .data
 RunPoisRegression_Omnibus_Multidose <- function(df, pyr0 = "pyr", event0 = "event", names = c("CONST"), term_n = c(0), tform = "loglin", keep_constant = c(0), a_n = c(0), modelform = "M", realization_columns = matrix(c("temp00", "temp01", "temp10", "temp11"), nrow = 2), realization_index = c("temp0", "temp1"), control = list(), strat_col = "null", model_control = list(), cons_mat = as.matrix(c(0)), cons_vec = c(0)) {
   func_t_start <- Sys.time()
+  initial_size <- nrow(df)
   if (class(df)[[1]] != "data.table") {
     tryCatch(
       {
-        setDT(df) # nocov
+        setDT(df)
       },
-      error = function(e) { # nocov
-        df <- data.table(df) # nocov
+      error = function(e) {
+        df <- data.table(df)
       }
     )
   }
@@ -468,32 +451,23 @@ RunPoisRegression_Omnibus_Multidose <- function(df, pyr0 = "pyr", event0 = "even
     model_control$MCML <- FALSE
   }
   if (model_control$strata == TRUE) {
-    val <- factorize(df, strat_col)
-    df0 <- val$df
-    df <- val$df
-    val_cols <- c()
-    for (col in val$cols) {
-      dftemp <- df[get(col) == 1, ]
-      temp <- sum(dftemp[, get(event0)])
-      if (temp == 0) {
-        if (control$verbose >= 2) {
-          warning(paste("Warning: no events for strata group:", col,
-            sep = " "
-          ))
-        }
-        df <- df[get(col) != 1, ]
-        df0 <- df0[get(col) != 1, ]
-      } else {
-        val_cols <- c(val_cols, col)
-      }
-      data.table::setkeyv(df0, c(pyr0, event0))
+    ## ------------------------------------------------------------------------------- ##
+    val <- Make_Interaction_Strata(df, event0, strat_col, control, TRUE, TRUE)
+    df <- val$data
+    val_cols <- val$combs
+    strata_vals <- val$levels
+    ## ------------------------------------------------------------------------------- ##
+    if (control$verbose >= 3) {
+      message(paste("Note: ", length(strat_col), " strata used",
+        sep = ""
+      ))
     }
   } else {
-    df0 <- data.table::data.table("a" = c(0, 0))
     val <- list(cols = c("a"))
-    val_cols <- c("a")
+    val_cols <- c(event0)
+    strata_vals <- c(1)
   }
-  data.table::setkeyv(df, c(pyr0, event0))
+  data.table::setkeyv(df, val_cols)
   #
   all_names <- unique(names)
   df <- Replace_Missing(df, all_names, 0.0, control$verbose)
@@ -527,12 +501,13 @@ RunPoisRegression_Omnibus_Multidose <- function(df, pyr0 = "pyr", event0 = "even
   term_tot <- max(term_n) + 1
   x_all <- as.matrix(df[, all_names, with = FALSE])
   dose_all <- as.matrix(df[, dose_names, with = FALSE])
+  run_size <- nrow(df)
   e <- pois_multidose_Omnibus_transition(
     as.matrix(df[, ce, with = FALSE]),
     term_n, tform, a_n,
     as.matrix(dose_cols, with = FALSE), dose_index, dfc, x_all, dose_all,
     0, modelform, control,
-    keep_constant, term_tot, as.matrix(df0[, val_cols, with = FALSE]),
+    keep_constant, term_tot, strata_vals, as.matrix(df[, val_cols, with = FALSE]),
     model_control, cons_mat, cons_vec
   )
   if ("Status" %in% names(e)) {
@@ -543,13 +518,14 @@ RunPoisRegression_Omnibus_Multidose <- function(df, pyr0 = "pyr", event0 = "even
   e$Parameter_Lists$names <- names
   e$Parameter_Lists$keep_constant <- keep_constant
   e$Parameter_Lists$modelformula <- modelform
-  if (model_control$MCML) {
-    e$Survival_Type <- "Pois_Multidose"
-  } else {
-    e$Survival_Type <- "Pois_Multidose"
+  if (model_control$strata == TRUE) {
+    e$strata_levels <- length(strata_vals)
   }
+  e$Survival_Type <- "Pois_Multidose"
   func_t_end <- Sys.time()
   e$RunTime <- func_t_end - func_t_start
+  e$UsedRecords <- run_size
+  e$RejectedRecords <- initial_size - run_size
   # df <- copy(df)
   return(e)
 }
