@@ -1,30 +1,34 @@
+//  Copyright 2022 - 2025, Eric Giunta and the project collaborators, Please see main R package for license and usage details
+
+#ifndef SRC_COLOSSUS_TYPES_H_
+#define SRC_COLOSSUS_TYPES_H_
+
 #include <RcppEigen.h>
+
 #ifdef _OPENMP
 #include <omp.h>
 #endif
+
+#include <Eigen/Core>
 #include <fstream>
 #include <sstream>
 #include <string>
 #include <vector>
-#include <chrono>
 #include <random>
 #include <ctime>
-#include <Eigen/Core>
+
 #include "R_Interface.h"
 
 
-// [[Rcpp::depends(RcppEigen)]]
-// [[Rcpp::plugins(openmp)]]
-using namespace std;
-using namespace Rcpp;
-using namespace Eigen;
-using namespace std::chrono;
+//  [[Rcpp::depends(RcppEigen)]]
+//  [[Rcpp::plugins(openmp)]]
 
 using Eigen::Map;
+using Eigen::Ref;
 using Eigen::MatrixXd;
 using Eigen::SparseMatrix;
 using Eigen::VectorXd;
+
 using Rcpp::as;
 
-typedef Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic, ColMajor > ColXd;
-typedef Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic, RowMajor > RowXd;
+#endif  //  SRC_COLOSSUS_TYPES_H_
